magneticalc.Comparison_Types

# ``magneticalc`.`Comparison_Types``

module documentation

Comparison_Types module.

Function | `comparison_name_to_type` | Converts a comparison name to a comparison type.
Function | `comparison_type_safe` | A valid comparison type is passed through, but an invalid comparison type converts to the default type.
Function | `comparison_type_to_name` | Converts a comparison type to a comparison name.
Constant | `COMPARISON_TYPE_IN_RANGE` | Comparison type: Not In Range.
Constant | `COMPARISON_TYPE_NOT_IN_RANGE` | Map of comparison types to names.
Variable | `Comparison_Types_Names_Map` | Default comparison type.

def comparison_name_to_type(comparison_name: `str`) -> `int`:

Converts a comparison name to a comparison type.

Parameters
comparison_name: `str` | Comparison name @return Comparison type

Returns
`int` | Undocumented

def comparison_type_safe(comparison_type: `int`) -> `int`:

A valid comparison type is passed through, but an invalid comparison type converts to the default type.

Parameters
comparison_type: `int` | Comparison type

Returns
`int` | Safe comparison type

def comparison_type_to_name(comparison_type: `int`) -> `str`:

Converts a comparison type to a comparison name.

Parameters
comparison_type: `int` | Comparison type

Returns
`str` | Comparison name

COMPARISON_TYPE_IN_RANGE: `int` =

Comparison type: Not In Range.

Value
    0

COMPARISON_TYPE_NOT_IN_RANGE: `int` =

Map of comparison types to names.

Value
    1

Comparison_Types_Names_Map =

Default comparison type.